@@ -669,6 +669,53 @@ sub get_releases {
 
 }
 
+=head2 with_layer_features
+
+This is a modifier for any C<search()> which
+will add the following additional synthesized columns to the result set:
+
+=over 4
+
+=item is_discoverable
+
+=item is_macsuckable
+
+=item is_arpnipable
+
+=back
+
+=cut
+
+sub with_layer_features {
+  my ($rs, $cond, $attrs) = @_;
+
+  return $rs
+    ->search_rs($cond, $attrs)
+    ->search({},
+      {
+        '+columns' => {
+          is_discoverable =>
+            $rs->result_source->schema->resultset('DeviceSkip')
+              ->search(
+                { 'ds.device' => { -ident => 'me.ip' }, '-not' => \q{'discover' = ANY(actionset)} },
+                { alias => 'ds' },
+              )->count_rs->as_query,
+          is_macsuckable =>
+            $rs->result_source->schema->resultset('DeviceSkip')
+              ->search(
+                { 'ds.device' => { -ident => 'me.ip' }, '-not' => \q{'macsuck' = ANY(actionset)} },
+                { alias => 'ds' },
+              )->count_rs->as_query,
+          is_arpnipable =>
+            $rs->result_source->schema->resultset('DeviceSkip')
+              ->search(
+                { 'ds.device' => { -ident => 'me.ip' }, '-not' => \q{'arpnip' = ANY(actionset)} },
+                { alias => 'ds' },
+              )->count_rs->as_query,
+        },
+      });
+}
+
 =head2 with_port_count
 
 This is a modifier for any C<search()> which
